@@ -10,7 +10,6 @@ mod document;
 mod enum_def;
 mod enum_value;
 mod field;
-mod field_value;
 mod fragment;
 mod input_field;
 mod input_object_def;
@@ -22,6 +21,7 @@ mod scalar_def;
 mod schema_def;
 mod selection_set;
 mod string_value;
+mod ty;
 mod union_def;
 mod value;
 mod variable;
@@ -34,11 +34,10 @@ pub use document::Document;
 pub use enum_def::EnumDefinition;
 pub use enum_value::EnumValue;
 pub use field::{Field, FieldDefinition};
-pub use field_value::Type_;
 pub use fragment::{FragmentDefinition, FragmentSpread, InlineFragment, TypeCondition};
 pub use input_field::InputField;
 pub use input_object_def::InputObjectDefinition;
-pub use input_value::InputValueDef;
+pub use input_value::InputValueDefinition;
 pub use interface_def::InterfaceDefinition;
 pub use object_def::ObjectDefinition;
 pub use operation::{OperationDefinition, OperationType};
@@ -46,6 +45,7 @@ pub use scalar_def::ScalarDefinition;
 pub use schema_def::SchemaDefinition;
 pub use selection_set::{Selection, SelectionSet};
 pub use string_value::StringValue;
+pub use ty::Type_;
 pub use union_def::UnionDefinition;
 pub use value::Value;
 pub use variable::VariableDefinition;
