@@ -13,9 +13,9 @@ use crate::{Directive, StringValue};
 /// use apollo_encoder::ScalarDefinition;
 ///
 /// let mut scalar = ScalarDefinition::new("NumberOfTreatsPerDay".to_string());
-/// scalar.description(Some(
+/// scalar.description(
 ///     "Int representing number of treats received.".to_string(),
-/// ));
+/// );
 ///
 /// assert_eq!(
 ///     scalar.to_string(),
@@ -29,7 +29,7 @@ pub struct ScalarDefinition {
     // Name must return a String.
     name: String,
     // Description may return a String or null.
-    description: StringValue,
+    description: Option<StringValue>,
     directives: Vec<Directive>,
     extend: bool,
 }
@@ -39,17 +39,17 @@ impl ScalarDefinition {
     pub fn new(name: String) -> Self {
         Self {
             name,
-            description: StringValue::Top { source: None },
+            description: None,
             directives: Vec::new(),
             extend: false,
         }
     }
 
     /// Set the ScalarDef's description.
-    pub fn description(&mut self, description: Option<String>) {
-        self.description = StringValue::Top {
+    pub fn description(&mut self, description: String) {
+        self.description = Some(StringValue::Top {
             source: description,
-        };
+        });
     }
 
     /// Add a directive.
@@ -67,9 +67,10 @@ impl fmt::Display for ScalarDefinition {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         if self.extend {
             write!(f, "extend ")?;
-        } else {
-            write!(f, "{}", self.description)?;
+        } else if let Some(description) = &self.description {
+            write!(f, "{}", description)?;
         }
+
         write!(f, "scalar {}", self.name)?;
         for directive in &self.directives {
             write!(f, " {}", directive)?;
@@ -99,9 +100,7 @@ mod tests {
     #[test]
     fn it_encodes_scalar_with_description() {
         let mut scalar = ScalarDefinition::new("NumberOfTreatsPerDay".to_string());
-        scalar.description(Some(
-            "Int representing number of treats received.".to_string(),
-        ));
+        scalar.description("Int representing number of treats received.".to_string());
 
         assert_eq!(
             scalar.to_string(),
@@ -114,9 +113,7 @@ scalar NumberOfTreatsPerDay
     #[test]
     fn it_encodes_scalar_with_extend_directive() {
         let mut scalar = ScalarDefinition::new("NumberOfTreatsPerDay".to_string());
-        scalar.description(Some(
-            "Int representing number of treats received.".to_string(),
-        ));
+        scalar.description("Int representing number of treats received.".to_string());
         scalar.extend();
         let mut directive = Directive::new(String::from("tag"));
         directive.arg(Argument::new(
